@@ -185,6 +185,8 @@ enum VpKernelID
     kernelRenderCopy,
 
     kernelL0FcCommon,
+    kernelL0FcFP,
+    kernelL0Fc444PL3Input,
 
     baseKernelMaxNumID
 };
