@@ -28,7 +28,7 @@
 #define __VPHAL_RENDER_VEBOX_BASE_H__
 
 #include "mos_os.h"
-#include "renderhal.h"
+#include "renderhal_legacy.h"
 #include "mhw_vebox.h"
 #include "vphal.h"
 #include "vphal_render_renderstate.h"
@@ -631,6 +631,7 @@ public:
                                             bTopField      = false;
                                             bBeCsc         = false;
                                             bFeCsc         = false;
+                                            bCcmCsc        = false;
                                             bVeboxBypass   = false;
                                             b60fpsDi       = false;
                                             bQueryVariance = false;
@@ -725,6 +726,7 @@ public:
     bool                                bTopField;
     bool                                bBeCsc;
     bool                                bFeCsc;
+    bool                                bCcmCsc;
     bool                                bVeboxBypass;
     bool                                b60fpsDi;
     bool                                bQueryVariance;
@@ -1248,7 +1250,12 @@ public:
 
     virtual bool IsIECPEnabled()
     {
-        return GetLastExecRenderData()->bIECP;
+        PVPHAL_VEBOX_RENDER_DATA pRenderData = GetLastExecRenderData();
+        VPHAL_RENDER_CHK_NULL_NO_STATUS(pRenderData);
+
+        return pRenderData->bIECP;
+    finish:
+        return false;
     }
     virtual bool IsQueryVarianceEnabled() {return false;}
 
@@ -1281,6 +1288,11 @@ protected:
     virtual MOS_STATUS VeboxSetDNDIParams(
         PVPHAL_SURFACE              pSrcSurface);
 
+    virtual bool IsDnDisabled()
+    {
+        return false;
+    }
+
     //!
     //! \brief    Vebox Set FMD parameter
     //! \details  Set up the FMD parameters for DNDI State
