@@ -137,7 +137,7 @@ public:
         return formattedOpCode;
     }
 
-    MOS_STATUS SetWatchdogTimerThreshold(uint32_t frameWidth, uint32_t frameHeight, bool isEncoder) override
+    MOS_STATUS SetWatchdogTimerThreshold(uint32_t frameWidth, uint32_t frameHeight, bool isEncoder, uint32_t codecMode) override
     {
         return MOS_STATUS_SUCCESS;
     }
@@ -283,28 +283,7 @@ public:
     MOS_STATUS AddVeboxMMIOPrologCmd(
         PMOS_COMMAND_BUFFER cmdBuffer) override
     {
-        MOS_STATUS eStatus          = MOS_STATUS_SUCCESS;
-        uint64_t   auxTableBaseAddr = 0;
-
-        MHW_CHK_NULL_RETURN(cmdBuffer);
-        MHW_CHK_NULL_RETURN(this->m_osItf);
-
-        auxTableBaseAddr = this->m_osItf->pfnGetAuxTableBaseAddr(this->m_osItf);
-
-        if (auxTableBaseAddr)
-        {
-            auto &par      = MHW_GETPAR_F(MI_LOAD_REGISTER_IMM)();
-            par            = {};
-            par.dwData     = (auxTableBaseAddr & 0xffffffff);
-            par.dwRegister = GetMmioInterfaces(mhw::mi::MHW_MMIO_VE0_AUX_TABLE_BASE_LOW);
-            MHW_ADDCMD_F(MI_LOAD_REGISTER_IMM)(cmdBuffer);
-
-            par.dwData     = ((auxTableBaseAddr >> 32) & 0xffffffff);
-            par.dwRegister = GetMmioInterfaces(mhw::mi::MHW_MMIO_VE0_AUX_TABLE_BASE_HIGH);
-            MHW_ADDCMD_F(MI_LOAD_REGISTER_IMM)(cmdBuffer);
-        }
-
-        return eStatus;
+        return MOS_STATUS_SUCCESS;
     }
 
      virtual MOS_STATUS AddBLTMMIOPrologCmd(
