@@ -287,7 +287,7 @@ struct _MHW_PAR_T(MFX_AVC_IMG_STATE)
     uint32_t                  numMBs                                       = 0;
     uint32_t                  imgStructImageStructureImgStructure10        = 0;
     uint32_t                  interViewOrderDisable                        = 0;
-    bool                      mfxAvcImgStatePar0                           = false;
+    bool                      vdaqmEnable                                  = false;
     
     __MHW_VDBOX_MFX_WRAPPER_EXT(MFX_AVC_IMG_STATE_CMDPAR_EXT);
 };
