@@ -50,7 +50,11 @@ MediaPipeline::MediaPipeline(PMOS_INTERFACE osInterface) : m_osInterface(osInter
     }
     else
     {
-        perfProfiler->Initialize((void *)this, m_osInterface);
+        MOS_STATUS status = perfProfiler->Initialize((void *)this, m_osInterface);
+        if (status != MOS_STATUS_SUCCESS)
+        {
+            MOS_OS_ASSERTMESSAGE("Initialize perfProfiler failed!");
+        }
     }
 }
 
@@ -150,12 +154,20 @@ MediaPacket *MediaPipeline::GetOrCreate(uint32_t packetId)
     auto iterCreator = m_packetCreators.find(packetId);
     if (iterCreator != m_packetCreators.end())
     {
-        RegisterPacket(packetId, iterCreator->second());
+        MOS_STATUS registStatus = RegisterPacket(packetId, iterCreator->second());
+        if (MOS_FAILED(registStatus))
+        {
+            MOS_OS_ASSERTMESSAGE("Media register packets into packet pool failed!");
+        }
 
         iter = m_packetList.find(packetId);
         if (iter != m_packetList.end())
         {
-            iter->second->Init();
+            MOS_STATUS status = iter->second->Init();
+            if (MOS_FAILED(status))
+            {
+                MOS_OS_ASSERTMESSAGE("Media packet init failed!");
+            }
             return iter->second;
         }
     }
