@@ -440,7 +440,7 @@ protected:
     // If queryAssignment == false, query whether STMM needed to be allocated.
     bool VeboxSTMMNeeded(VP_EXECUTE_CAPS& caps, bool queryAssignment);
     virtual uint32_t GetHistogramSurfaceSize(VP_EXECUTE_CAPS& caps, uint32_t inputWidth, uint32_t inputHeight);
-    virtual uint32_t Get3DLutSize(uint32_t &lutWidth, uint32_t &lutHeight);
+    virtual uint32_t Get3DLutSize(bool is33LutSizeEnabled, uint32_t &lutWidth, uint32_t &lutHeight);
     virtual uint32_t Get1DLutSize();
     virtual Mos_MemPool GetHistStatMemType(VP_EXECUTE_CAPS &caps);
     MOS_STATUS ReAllocateVeboxOutputSurface(VP_EXECUTE_CAPS& caps, VP_SURFACE *inputSurface, VP_SURFACE *outputSurface, bool &allocated);
@@ -511,6 +511,7 @@ protected:
     VP_SURFACE *m_vebox3DLookUpTables                        = nullptr;
     VP_SURFACE *m_vebox3DLookUpTables2D                      = nullptr;
     VP_SURFACE *m_vebox1DLookUpTables                        = nullptr;
+    VP_SURFACE *m_innerTileConvertInput                      = nullptr;
     VP_SURFACE *m_veboxDnHVSTables                           = nullptr;
     VP_SURFACE *m_3DLutKernelCoefSurface                     = nullptr;       //!< Coef surface for 3DLut kernel.
     uint32_t    m_currentDnOutput                            = 0;
@@ -551,6 +552,7 @@ protected:
 
     // Fc Resource
     VP_SURFACE *m_cmfcCoeff                                   = nullptr;
+    VP_SURFACE *m_fcIntermediaSurfaceInput[8]                 = {};
     //for decompreesion sync on interlace input of FC
     VP_SURFACE *m_decompressionSyncSurface                                  = nullptr;
     // Hdr Resource
