@@ -302,6 +302,7 @@ typedef struct _VEBOX_PACKET_SURFACE_PARAMS
     VP_SURFACE                      *pLaceOrAceOrRgbHistogram;
     VP_SURFACE                      *pSurfSkinScoreOutput;
     VP_SURFACE                      *pFMDHistorySurface;
+    VP_SURFACE                      *pInnerTileConvertInput;
 }VEBOX_PACKET_SURFACE_PARAMS, *PVEBOX_PACKET_SURFACE_PARAMS;
 };
 
@@ -921,6 +922,16 @@ public:
         uint32_t *pStatSlice0GNEPtr,
         uint32_t *pStatSlice1GNEPtr);
 
+    MOS_STATUS InitVeboxSurfaceStateCmdParamsForTileConvert(
+        PMHW_VEBOX_SURFACE_STATE_CMD_PARAMS mhwVeboxSurfaceStateCmdParams,
+        PMOS_SURFACE                        inputSurface,
+        PMOS_SURFACE                        outputSurface);
+
+    MOS_STATUS AddTileConvertStates(
+        MOS_COMMAND_BUFFER *CmdBuffer,
+        MHW_VEBOX_SURFACE_STATE_CMD_PARAMS &MhwVeboxSurfaceStateCmdParams);
+
+    MOS_FORMAT AdjustFormatForTileConvert(MOS_FORMAT format);
     // TGNE
     uint32_t dwGlobalNoiseLevel_Temporal  = 0;  //!< Global Temporal Noise Level for Y
     uint32_t dwGlobalNoiseLevelU_Temporal = 0;  //!< Global Temporal Noise Level for U
@@ -1203,6 +1214,7 @@ protected:
     VP_SURFACE                  *m_currentSurface           = nullptr;              //!< Current frame
     VP_SURFACE                  *m_previousSurface          = nullptr;              //!< Previous frame
     VP_SURFACE                  *m_renderTarget             = nullptr;              //!< Render Target frame
+    VP_SURFACE                  *m_originalOutput           = nullptr;              //!< Render Target frame
 
     uint32_t                    m_dwGlobalNoiseLevelU = 0;                        //!< Global Noise Level for U
     uint32_t                    m_dwGlobalNoiseLevelV = 0;                        //!< Global Noise Level for V
